@@ -1,36 +1,21 @@
 /*
-    Copyright 2013 Lukas Tinkl <ltinkl@redhat.com>
-    Copyright 2013 by Daniel Nicoletti <dantti12@gmail.com>
+    SPDX-FileCopyrightText: 2013 Lukas Tinkl <ltinkl@redhat.com>
+    SPDX-FileCopyrightText: 2013 Daniel Nicoletti <dantti12@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#include "debug.h"
 #include "passworddialog.h"
+#include "debug.h"
 #include "ui_passworddialog.h"
 #include "uiutils.h"
 
 #include <vpnuiplugin.h>
 
-#include <NetworkManagerQt/WirelessSetting>
-#include <NetworkManagerQt/VpnSetting>
 #include <NetworkManagerQt/Utils>
+#include <NetworkManagerQt/VpnSetting>
+#include <NetworkManagerQt/WirelessSetting>
 
-#include <KServiceTypeTrader>
 #include <KLocalizedString>
 
 #include <QIcon>
@@ -38,17 +23,20 @@
 
 using namespace NetworkManager;
 
-PasswordDialog::PasswordDialog(const NetworkManager::ConnectionSettings::Ptr &connectionSettings, SecretAgent::GetSecretsFlags flags,
-                               const QString &setting_name, const QStringList &hints, QWidget *parent) :
-    QDialog(parent),
-    m_ui(nullptr),
-    m_hasError(false),
-    m_settingName(setting_name),
-    m_connectionSettings(connectionSettings),
-    m_error(SecretAgent::NoSecrets),
-    m_flags(flags),
-    m_vpnWidget(nullptr),
-    m_hints(hints)
+PasswordDialog::PasswordDialog(const NetworkManager::ConnectionSettings::Ptr &connectionSettings,
+                               SecretAgent::GetSecretsFlags flags,
+                               const QString &setting_name,
+                               const QStringList &hints,
+                               QWidget *parent)
+    : QDialog(parent)
+    , m_ui(nullptr)
+    , m_hasError(false)
+    , m_settingName(setting_name)
+    , m_connectionSettings(connectionSettings)
+    , m_error(SecretAgent::NoSecrets)
+    , m_flags(flags)
+    , m_vpnWidget(nullptr)
+    , m_hints(hints)
 {
     setWindowIcon(QIcon::fromTheme(QStringLiteral("dialog-password")));
 
@@ -70,10 +58,10 @@ void PasswordDialog::initializeUi()
 
     connect(m_ui->buttonBox, &QDialogButtonBox::accepted, this, &PasswordDialog::accept);
     connect(m_ui->buttonBox, &QDialogButtonBox::rejected, this, &PasswordDialog::reject);
-    connect(m_ui->password, &PasswordField::textChanged, [this](const QString &text){
+    connect(m_ui->password, &PasswordField::textChanged, [this](const QString &text) {
         if (m_connectionSettings->connectionType() == NetworkManager::ConnectionSettings::Wireless) {
             NetworkManager::WirelessSecuritySetting::Ptr wirelessSecuritySetting =
-                    m_connectionSettings->setting(NetworkManager::Setting::WirelessSecurity).staticCast<NetworkManager::WirelessSecuritySetting>();
+                m_connectionSettings->setting(NetworkManager::Setting::WirelessSecurity).staticCast<NetworkManager::WirelessSecuritySetting>();
             bool valid = true;
 
             if (wirelessSecuritySetting) {
@@ -127,22 +115,14 @@ void PasswordDialog::initializeUi()
             m_error = SecretAgent::InternalError;
             m_errorMessage = QLatin1String("VPN settings are missing");
         } else {
-            VpnUiPlugin *vpnUiPlugin;
-            QString error;
             const QString serviceType = vpnSetting->serviceType();
-            vpnUiPlugin = KServiceTypeTrader::createInstanceFromQuery<VpnUiPlugin>(QLatin1String("PlasmaNetworkManagement/VpnUiPlugin"),
-                                                                                   QString::fromLatin1("[X-NetworkManager-Services]=='%1'").arg(serviceType),
-                                                                                   this, QVariantList(), &error);
-            if (vpnUiPlugin && error.isEmpty()) {
+            const auto result = VpnUiPlugin::loadPluginForType(this, serviceType);
+
+            if (result) {
+                VpnUiPlugin *vpnUiPlugin = result.plugin;
                 const QString shortName = serviceType.section('.', -1);
                 NMStringMap data = vpnSetting->data();
-                // If we have hints, make the user have them through the widget
-                if (!m_hints.isEmpty() && m_hints.size() == 2) {
-                    data.insert("hint", m_hints[0]);
-                    data.insert("hint-msg", m_hints[1]);
-                    vpnSetting->setData(data);
-                }
-                m_vpnWidget = vpnUiPlugin->askUser(vpnSetting, this);
+                m_vpnWidget = vpnUiPlugin->askUser(vpnSetting, m_hints, this);
                 QVBoxLayout *layout = new QVBoxLayout();
                 layout->addWidget(m_vpnWidget);
                 m_ui->vpnWidget->setLayout(layout);
@@ -159,18 +139,11 @@ void PasswordDialog::initializeUi()
 
                 setFocusProxy(m_vpnWidget);
                 m_vpnWidget->setFocus(Qt::OtherFocusReason);
-
-                // Delete hins from vpnSetting
-                if (!m_hints.isEmpty()) {
-                    data.remove("hint");
-                    data.remove("hint-msg");
-                    vpnSetting->setData(data);
-                }
             } else {
-                qCWarning(PLASMA_NM) << error << ", serviceType == " << serviceType;
+                qCWarning(PLASMA_NM) << "Could not load VPN UI plugin" << result.errorText;
                 m_hasError = true;
                 m_error = SecretAgent::InternalError;
-                m_errorMessage = error;
+                m_errorMessage = result.errorString;
             }
         }
     }
