@@ -1,22 +1,8 @@
 /*
-    Copyright 2013 Lukas Tinkl <ltinkl@redhat.com>
-    Copyright 2013 by Daniel Nicoletti <dantti12@gmail.com>
+    SPDX-FileCopyrightText: 2013 Lukas Tinkl <ltinkl@redhat.com>
+    SPDX-FileCopyrightText: 2013 Daniel Nicoletti <dantti12@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef PLASMA_NM_PASSWORD_DIALOG_H
@@ -27,7 +13,8 @@
 
 #include <QDialog>
 
-namespace Ui {
+namespace Ui
+{
 class PasswordDialog;
 }
 
@@ -39,7 +26,8 @@ class Q_DECL_EXPORT PasswordDialog : public QDialog
 public:
     explicit PasswordDialog(const NetworkManager::ConnectionSettings::Ptr &connectionSettings,
                             NetworkManager::SecretAgent::GetSecretsFlags flags,
-                            const QString &setting_name, const QStringList &hints = QStringList(),
+                            const QString &setting_name,
+                            const QStringList &hints = QStringList(),
                             QWidget *parent = nullptr);
     ~PasswordDialog() override;
 
@@ -62,7 +50,6 @@ private:
     NetworkManager::SecretAgent::GetSecretsFlags m_flags;
     SettingWidget *m_vpnWidget;
     QStringList m_hints;
-
 };
 
 #endif // PLASMA_NM_PASSWORD_DIALOG_H
