@@ -1,44 +1,30 @@
 /*
-    Copyright 2013 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2013 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "connectionwidget.h"
-#include "ui_connectionwidget.h"
 #include "advancedpermissionswidget.h"
+#include "ui_connectionwidget.h"
 
-#include <NetworkManagerQt/Settings>
 #include <NetworkManagerQt/Connection>
+#include <NetworkManagerQt/Settings>
 
-#include <QDBusConnection>
-#include <QDialog>
-#include <QVBoxLayout>
-#include <QDialogButtonBox>
-#include <KUser>
 #include <KAcceleratorManager>
 #include <KLocalizedString>
+#include <KUser>
+#include <QDBusConnection>
+#include <QDialog>
+#include <QDialogButtonBox>
+#include <QVBoxLayout>
 
-ConnectionWidget::ConnectionWidget(const NetworkManager::ConnectionSettings::Ptr &settings, QWidget* parent, Qt::WindowFlags f):
-    QWidget(parent, f),
-    m_widget(new Ui::ConnectionWidget),
-    m_type(settings->connectionType()),
-    m_masterUuid(settings->master()),
-    m_slaveType(settings->slaveType())
+ConnectionWidget::ConnectionWidget(const NetworkManager::ConnectionSettings::Ptr &settings, QWidget *parent, Qt::WindowFlags f)
+    : QWidget(parent, f)
+    , m_widget(new Ui::ConnectionWidget)
+    , m_type(settings->connectionType())
+    , m_masterUuid(settings->master())
+    , m_slaveType(settings->slaveType())
 {
     m_widget->setupUi(this);
 
@@ -163,8 +149,7 @@ void ConnectionWidget::autoVpnToggled(bool on)
 void ConnectionWidget::openAdvancedPermissions()
 {
     QPointer<AdvancedPermissionsWidget> dialog = new AdvancedPermissionsWidget(m_tmpSetting.permissions(), this);
-    dialog->setWindowTitle(i18nc("@title:window advanced permissions editor",
-                                 "Advanced Permissions Editor"));
+    dialog->setWindowTitle(i18nc("@title:window advanced permissions editor", "Advanced Permissions Editor"));
     if (dialog->exec() == QDialog::Accepted) {
         m_tmpSetting.setPermissions(dialog->currentUsers());
     }
@@ -178,7 +163,7 @@ NMStringMap ConnectionWidget::vpnConnections() const
 
     for (const NetworkManager::Connection::Ptr &conn : list) {
         NetworkManager::ConnectionSettings::Ptr conSet = conn->settings();
-        if (conSet->connectionType() == NetworkManager::ConnectionSettings::Vpn
+        if (conSet->connectionType() == NetworkManager::ConnectionSettings::Vpn //
             || conSet->connectionType() == NetworkManager::ConnectionSettings::WireGuard) {
             // qCDebug(PLASMA_NM) << "Found VPN" << conSet->id() << conSet->uuid();
             result.insert(conSet->uuid(), conSet->id());
@@ -190,7 +175,9 @@ NMStringMap ConnectionWidget::vpnConnections() const
 
 QStringList ConnectionWidget::firewallZones() const
 {
-    QDBusMessage msg = QDBusMessage::createMethodCall("org.fedoraproject.FirewallD1", "/org/fedoraproject/FirewallD1", "org.fedoraproject.FirewallD1.zone",
+    QDBusMessage msg = QDBusMessage::createMethodCall("org.fedoraproject.FirewallD1", //
+                                                      "/org/fedoraproject/FirewallD1",
+                                                      "org.fedoraproject.FirewallD1.zone",
                                                       "getZones");
     QDBusPendingReply<QStringList> reply = QDBusConnection::systemBus().asyncCall(msg);
     reply.waitForFinished();
@@ -202,7 +189,7 @@ QStringList ConnectionWidget::firewallZones() const
 
 void ConnectionWidget::populateVpnConnections()
 {
-    QMapIterator<QString,QString> it(vpnConnections());
+    QMapIterator<QString, QString> it(vpnConnections());
     while (it.hasNext()) {
         it.next();
         m_widget->vpnCombobox->addItem(it.value(), it.key());
