@@ -1,36 +1,22 @@
 /*
-    Copyright (c) 2013 Lukas Tinkl <ltinkl@redhat.com>
+    SPDX-FileCopyrightText: 2013 Lukas Tinkl <ltinkl@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#include "debug.h"
 #include "wificonnectionwidget.h"
+#include "debug.h"
 #include "ui_wificonnectionwidget.h"
 
-#include <NetworkManagerQt/Utils>
 #include <KLocalizedString>
+#include <NetworkManagerQt/Utils>
 #include <QRandomGenerator>
 
 #include "uiutils.h"
 
-WifiConnectionWidget::WifiConnectionWidget(const NetworkManager::Setting::Ptr &setting, QWidget* parent, Qt::WindowFlags f):
-    SettingWidget(setting, parent, f),
-    m_ui(new Ui::WifiConnectionWidget)
+WifiConnectionWidget::WifiConnectionWidget(const NetworkManager::Setting::Ptr &setting, QWidget *parent, Qt::WindowFlags f)
+    : SettingWidget(setting, parent, f)
+    , m_ui(new Ui::WifiConnectionWidget)
 {
     m_ui->setupUi(this);
 
@@ -133,7 +119,7 @@ void WifiConnectionWidget::generateRandomClonedMac()
 
     // Disable the multicast bit and enable the locally administered bit.
     mac[0] = mac[0] & ~0x1;
-    mac[0] = mac[0] |  0x2;
+    mac[0] = mac[0] | 0x2;
 
     m_ui->clonedMacAddress->setText(NetworkManager::macAddressAsString(mac));
 }
@@ -180,7 +166,7 @@ void WifiConnectionWidget::bandChanged(int band)
 
 void WifiConnectionWidget::fillChannels(NetworkManager::WirelessSetting::FrequencyBand band)
 {
-    QList<QPair<int, int> > channels;
+    QList<QPair<int, int>> channels;
 
     if (band == NetworkManager::WirelessSetting::A) {
         channels = NetworkManager::getAFreqs();
@@ -191,9 +177,9 @@ void WifiConnectionWidget::fillChannels(NetworkManager::WirelessSetting::Frequen
         return;
     }
 
-    QListIterator<QPair<int,int> > i(channels);
+    QListIterator<QPair<int, int>> i(channels);
     while (i.hasNext()) {
-        QPair<int,int> channel = i.next();
+        QPair<int, int> channel = i.next();
         m_ui->channel->addItem(i18n("%1 (%2 MHz)", channel.first, channel.second), channel.first);
     }
 }
