@@ -1,41 +1,28 @@
 /*
-Copyright 2011 Ilia Kats <ilia-kats@gmx.net>
+    SPDX-FileCopyrightText: 2011 Ilia Kats <ilia-kats@gmx.net>
 
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License as
-published by the Free Software Foundation; either version 2 of
-the License or (at your option) version 3 or any later version
-accepted by the membership of KDE e.V. (or its successor approved
-by the membership of KDE e.V.), which shall act as a proxy
-defined in Section 14 of version 3 of the license.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
+#include <QNetworkAddressEntry>
 #include <QStandardItem>
 #include <QStandardItemModel>
-#include <QNetworkAddressEntry>
 
 #include <KAcceleratorManager>
 #include <KLocalizedString>
 
-#include "ui_ipv4routes.h"
-#include "ipv4routeswidget.h"
-#include "ipv4delegate.h"
 #include "intdelegate.h"
+#include "ipv4delegate.h"
+#include "ipv4routeswidget.h"
+#include "ui_ipv4routes.h"
 
 class IpV4RoutesWidget::Private
 {
 public:
-    Private() : model(0,4)
+    Private()
+        : model(0, 4)
     {
-        QStandardItem * headerItem = new QStandardItem(i18nc("Header text for IPv4 address", "Address"));
+        QStandardItem *headerItem = new QStandardItem(i18nc("Header text for IPv4 address", "Address"));
         model.setHorizontalHeaderItem(0, headerItem);
         headerItem = new QStandardItem(i18nc("Header text for IPv4 netmask", "Netmask"));
         model.setHorizontalHeaderItem(1, headerItem);
@@ -48,8 +35,9 @@ public:
     QStandardItemModel model;
 };
 
-IpV4RoutesWidget::IpV4RoutesWidget(QWidget * parent)
-    : QDialog(parent), d(new IpV4RoutesWidget::Private())
+IpV4RoutesWidget::IpV4RoutesWidget(QWidget *parent)
+    : QDialog(parent)
+    , d(new IpV4RoutesWidget::Private())
 {
     d->ui.setupUi(this);
     d->ui.tableViewAddresses->setModel(&d->model);
@@ -109,13 +97,12 @@ void IpV4RoutesWidget::setRoutes(const QList<NetworkManager::IpRoute> &list)
 {
     d->model.removeRows(0, d->model.rowCount());
     for (const NetworkManager::IpRoute &route : list) {
-        QList<QStandardItem *> item;
-
-        // qCDebug(PLASMA_NM) << route.ip();
-        item << new QStandardItem(route.ip().toString())
-             << new QStandardItem(route.netmask().toString())
-             << new QStandardItem(route.nextHop().toString())
-             << new QStandardItem(QString::number(route.metric(), 10));
+        QList<QStandardItem *> item{
+            new QStandardItem(route.ip().toString()),
+            new QStandardItem(route.netmask().toString()),
+            new QStandardItem(route.nextHop().toString()),
+            new QStandardItem(QString::number(route.metric(), 10)),
+        };
 
         d->model.appendRow(item);
     }
@@ -127,7 +114,7 @@ QList<NetworkManager::IpRoute> IpV4RoutesWidget::routes()
 
     for (int i = 0, rowCount = d->model.rowCount(); i < rowCount; i++) {
         NetworkManager::IpRoute route;
-        QStandardItem *item = d->model.item(i,0);
+        QStandardItem *item = d->model.item(i, 0);
         if (item) {
             route.setIp(QHostAddress(item->text()));
         }
@@ -151,15 +138,14 @@ QList<NetworkManager::IpRoute> IpV4RoutesWidget::routes()
 
 void IpV4RoutesWidget::addRoute()
 {
-    QList<QStandardItem *> item;
-    item << new QStandardItem << new QStandardItem << new QStandardItem;
+    QList<QStandardItem *> item{new QStandardItem, new QStandardItem, new QStandardItem};
     d->model.appendRow(item);
 
     const int rowCount = d->model.rowCount();
     if (rowCount > 0) {
         d->ui.tableViewAddresses->selectRow(rowCount - 1);
 
-        QItemSelectionModel * selectionModel = d->ui.tableViewAddresses->selectionModel();
+        QItemSelectionModel *selectionModel = d->ui.tableViewAddresses->selectionModel();
         QModelIndexList list = selectionModel->selectedIndexes();
         if (list.size()) {
             // QTableView is configured to select only rows.
@@ -171,7 +157,7 @@ void IpV4RoutesWidget::addRoute()
 
 void IpV4RoutesWidget::removeRoute()
 {
-    QItemSelectionModel * selectionModel = d->ui.tableViewAddresses->selectionModel();
+    QItemSelectionModel *selectionModel = d->ui.tableViewAddresses->selectionModel();
     if (selectionModel->hasSelection()) {
         QModelIndexList indexes = selectionModel->selectedIndexes();
         d->model.takeRow(indexes[0].row());
@@ -179,7 +165,7 @@ void IpV4RoutesWidget::removeRoute()
     d->ui.pushButtonRemove->setEnabled(d->ui.tableViewAddresses->selectionModel()->hasSelection());
 }
 
-void IpV4RoutesWidget::selectionChanged(const QItemSelection & selected)
+void IpV4RoutesWidget::selectionChanged(const QItemSelection &selected)
 {
     // qCDebug(PLASMA_NM) << "selectionChanged";
     d->ui.pushButtonRemove->setEnabled(!selected.isEmpty());
