@@ -1,21 +1,7 @@
 /*
-    Copyright 2013-2018 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2013-2018 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 #include "networkmodelitem.h"
 #include "uiutils.h"
@@ -41,9 +27,9 @@
 #if WITH_MODEMMANAGER_SUPPORT
 #include <ModemManagerQt/manager.h>
 #include <ModemManagerQt/modem.h>
-#include <ModemManagerQt/modemdevice.h>
 #include <ModemManagerQt/modem3gpp.h>
 #include <ModemManagerQt/modemcdma.h>
+#include <ModemManagerQt/modemdevice.h>
 #endif
 
 NetworkModelItem::NetworkModelItem(QObject *parent)
@@ -176,7 +162,7 @@ bool NetworkModelItem::duplicate() const
     return m_duplicate;
 }
 
-void NetworkModelItem::setIcon(const QString& icon)
+void NetworkModelItem::setIcon(const QString &icon)
 {
     if (icon != m_icon) {
         m_icon = icon;
@@ -192,76 +178,77 @@ void NetworkModelItem::refreshIcon()
 QString NetworkModelItem::computeIcon() const
 {
     switch (m_type) {
-        case NetworkManager::ConnectionSettings::Adsl:
+    case NetworkManager::ConnectionSettings::Adsl:
+        return QStringLiteral("network-mobile-100");
+        break;
+    case NetworkManager::ConnectionSettings::Bluetooth:
+        if (m_connectionState == NetworkManager::ActiveConnection::Activated) {
+            return QStringLiteral("network-bluetooth-activated");
+        } else {
+            return QStringLiteral("network-bluetooth");
+        }
+        break;
+    case NetworkManager::ConnectionSettings::Bond:
+        break;
+    case NetworkManager::ConnectionSettings::Bridge:
+        break;
+    case NetworkManager::ConnectionSettings::Cdma:
+    case NetworkManager::ConnectionSettings::Gsm:
+        if (m_signal == 0) {
+            return QStringLiteral("network-mobile-0");
+        } else if (m_signal < 20) {
+            return QStringLiteral("network-mobile-20");
+        } else if (m_signal < 40) {
+            return QStringLiteral("network-mobile-40");
+        } else if (m_signal < 60) {
+            return QStringLiteral("network-mobile-60");
+        } else if (m_signal < 80) {
+            return QStringLiteral("network-mobile-80");
+        } else {
             return QStringLiteral("network-mobile-100");
-            break;
-        case NetworkManager::ConnectionSettings::Bluetooth:
-            if (m_connectionState == NetworkManager::ActiveConnection::Activated) {
-                return QStringLiteral("network-bluetooth-activated");
-            } else {
-                return QStringLiteral("network-bluetooth");
+        }
+        break;
+    case NetworkManager::ConnectionSettings::Infiniband:
+        break;
+    case NetworkManager::ConnectionSettings::OLPCMesh:
+        break;
+    case NetworkManager::ConnectionSettings::Pppoe:
+        return QStringLiteral("network-mobile-100");
+        break;
+    case NetworkManager::ConnectionSettings::Vlan:
+        break;
+    case NetworkManager::ConnectionSettings::Vpn:
+    case NetworkManager::ConnectionSettings::WireGuard:
+        return QStringLiteral("network-vpn");
+        break;
+    case NetworkManager::ConnectionSettings::Wired:
+        if (m_connectionState == NetworkManager::ActiveConnection::Activated) {
+            return QStringLiteral("network-wired-activated");
+        } else {
+            return QStringLiteral("network-wired");
+        }
+        break;
+    case NetworkManager::ConnectionSettings::Wireless:
+        if (m_signal == 0) {
+            if (m_mode == NetworkManager::WirelessSetting::Adhoc || m_mode == NetworkManager::WirelessSetting::Ap) {
+                return (m_securityType <= NetworkManager::NoneSecurity) ? QStringLiteral("network-wireless-100")
+                                                                        : QStringLiteral("network-wireless-100-locked");
             }
-            break;
-        case NetworkManager::ConnectionSettings::Bond:
-            break;
-        case NetworkManager::ConnectionSettings::Bridge:
-            break;
-        case NetworkManager::ConnectionSettings::Cdma:
-        case NetworkManager::ConnectionSettings::Gsm:
-            if (m_signal == 0 ) {
-                return QStringLiteral("network-mobile-0");
-            } else if (m_signal < 20) {
-                return QStringLiteral("network-mobile-20");
-            } else if (m_signal < 40) {
-                return QStringLiteral("network-mobile-40");
-            } else if (m_signal < 60) {
-                return QStringLiteral("network-mobile-60");
-            } else if (m_signal < 80) {
-                return QStringLiteral("network-mobile-80");
-            } else {
-                return QStringLiteral("network-mobile-100");
-            }
-            break;
-        case NetworkManager::ConnectionSettings::Infiniband:
-            break;
-        case NetworkManager::ConnectionSettings::OLPCMesh:
-            break;
-        case NetworkManager::ConnectionSettings::Pppoe:
-            return QStringLiteral("network-mobile-100");
-            break;
-        case NetworkManager::ConnectionSettings::Vlan:
-            break;
-        case NetworkManager::ConnectionSettings::Vpn:
-        case NetworkManager::ConnectionSettings::WireGuard:
-            return QStringLiteral("network-vpn");
-            break;
-        case NetworkManager::ConnectionSettings::Wired:
-            if (m_connectionState == NetworkManager::ActiveConnection::Activated) {
-                return QStringLiteral("network-wired-activated");
-            } else {
-                return QStringLiteral("network-wired");
-            }
-            break;
-        case NetworkManager::ConnectionSettings::Wireless:
-            if (m_signal == 0 ) {
-                if (m_mode == NetworkManager::WirelessSetting::Adhoc || m_mode == NetworkManager::WirelessSetting::Ap) {
-                    return (m_securityType <= NetworkManager::NoneSecurity) ? QStringLiteral("network-wireless-100") : QStringLiteral("network-wireless-100-locked");
-                }
-                return (m_securityType <= NetworkManager::NoneSecurity) ? QStringLiteral("network-wireless-0") : QStringLiteral("network-wireless-0-locked");
-            } else if (m_signal < 20) {
-                return (m_securityType <= NetworkManager::NoneSecurity) ? QStringLiteral("network-wireless-20") : QStringLiteral("network-wireless-20-locked");
-            } else if (m_signal < 40) {
-                return (m_securityType <= NetworkManager::NoneSecurity) ? QStringLiteral("network-wireless-40") : QStringLiteral("network-wireless-40-locked");
-            } else if (m_signal < 60) {
-                return (m_securityType <= NetworkManager::NoneSecurity) ? QStringLiteral("network-wireless-60") : QStringLiteral("network-wireless-60-locked");
-            } else if (m_signal < 80) {
-                return (m_securityType <= NetworkManager::NoneSecurity) ? QStringLiteral("network-wireless-80") : QStringLiteral("network-wireless-80-locked");
-            } else {
-                return (m_securityType <= NetworkManager::NoneSecurity) ? QStringLiteral("network-wireless-100") : QStringLiteral("network-wireless-100-locked");
-            }
-            break;
-        default:
-            break;
+            return (m_securityType <= NetworkManager::NoneSecurity) ? QStringLiteral("network-wireless-0") : QStringLiteral("network-wireless-0-locked");
+        } else if (m_signal < 20) {
+            return (m_securityType <= NetworkManager::NoneSecurity) ? QStringLiteral("network-wireless-20") : QStringLiteral("network-wireless-20-locked");
+        } else if (m_signal < 40) {
+            return (m_securityType <= NetworkManager::NoneSecurity) ? QStringLiteral("network-wireless-40") : QStringLiteral("network-wireless-40-locked");
+        } else if (m_signal < 60) {
+            return (m_securityType <= NetworkManager::NoneSecurity) ? QStringLiteral("network-wireless-60") : QStringLiteral("network-wireless-60-locked");
+        } else if (m_signal < 80) {
+            return (m_securityType <= NetworkManager::NoneSecurity) ? QStringLiteral("network-wireless-80") : QStringLiteral("network-wireless-80-locked");
+        } else {
+            return (m_securityType <= NetworkManager::NoneSecurity) ? QStringLiteral("network-wireless-100") : QStringLiteral("network-wireless-100-locked");
+        }
+        break;
+    default:
+        break;
     }
 
     if (m_connectionState == NetworkManager::ActiveConnection::Activated) {
@@ -273,14 +260,15 @@ QString NetworkModelItem::computeIcon() const
 
 NetworkModelItem::ItemType NetworkModelItem::itemType() const
 {
-    if (!m_devicePath.isEmpty() ||
-        m_type == NetworkManager::ConnectionSettings::Bond ||
-        m_type == NetworkManager::ConnectionSettings::Bridge ||
-        m_type == NetworkManager::ConnectionSettings::Vlan ||
-        m_type == NetworkManager::ConnectionSettings::Team ||
-        ((NetworkManager::status() == NetworkManager::Connected ||
-          NetworkManager::status() == NetworkManager::ConnectedLinkLocal ||
-          NetworkManager::status() == NetworkManager::ConnectedSiteOnly) && (m_type == NetworkManager::ConnectionSettings::Vpn || m_type == NetworkManager::ConnectionSettings::WireGuard))) {
+    if (!m_devicePath.isEmpty() //
+        || m_type == NetworkManager::ConnectionSettings::Bond //
+        || m_type == NetworkManager::ConnectionSettings::Bridge //
+        || m_type == NetworkManager::ConnectionSettings::Vlan //
+        || m_type == NetworkManager::ConnectionSettings::Team //
+        || ((NetworkManager::status() == NetworkManager::Connected //
+             || NetworkManager::status() == NetworkManager::ConnectedLinkLocal //
+             || NetworkManager::status() == NetworkManager::ConnectedSiteOnly)
+            && (m_type == NetworkManager::ConnectionSettings::Vpn || m_type == NetworkManager::ConnectionSettings::WireGuard))) {
         if (m_connectionPath.isEmpty() && m_type == NetworkManager::ConnectionSettings::Wireless) {
             return NetworkModelItem::AvailableAccessPoint;
         } else {
@@ -328,7 +316,7 @@ QString NetworkModelItem::sectionType() const
 {
     if (m_connectionState == NetworkManager::ActiveConnection::Deactivated) {
         return "Available connections";
-    }  else {
+    } else {
         return QString();
     }
 }
@@ -534,11 +522,11 @@ void NetworkModelItem::updateDetails() const
 
     NetworkManager::Device::Ptr device = NetworkManager::findNetworkInterface(m_devicePath);
 
-    // Get IPv[46]Address and related nameservers + IPv4 default gateway
+    // Get IPv[46]Address and related nameservers + IPv[46] default gateway
     if (device && device->ipV4Config().isValid() && m_connectionState == NetworkManager::ActiveConnection::Activated) {
         if (!device->ipV4Config().addresses().isEmpty()) {
             QHostAddress addr = device->ipV4Config().addresses().first().ip();
-            if (!addr.isNull()) {
+            if (!addr.isNull() && addr.isGlobal()) {
                 m_details << i18n("IPv4 Address") << addr.toString();
             }
         }
@@ -549,9 +537,15 @@ void NetworkModelItem::updateDetails() const
             }
         }
         if (!device->ipV4Config().nameservers().isEmpty()) {
-            QHostAddress addr = device->ipV4Config().nameservers().first();
-            if (!addr.isNull()) {
-                m_details << i18n("IPv4 Nameserver") << addr.toString();
+            QHostAddress addr1 = device->ipV4Config().nameservers().first();
+            QHostAddress addr2 = device->ipV4Config().nameservers().last();
+            if (!addr1.isNull()) {
+                m_details << i18n("IPv4 Primary Nameserver") << addr1.toString();
+            }
+            if (!addr2.isNull() && !addr1.isNull()) {
+                if (addr2 != addr1) {
+                    m_details << i18n("IPv4 Secondary Nameserver") << addr2.toString();
+                }
             }
         }
     }
@@ -559,14 +553,28 @@ void NetworkModelItem::updateDetails() const
     if (device && device->ipV6Config().isValid() && m_connectionState == NetworkManager::ActiveConnection::Activated) {
         if (!device->ipV6Config().addresses().isEmpty()) {
             QHostAddress addr = device->ipV6Config().addresses().first().ip();
-            if (!addr.isNull()) {
+            if (!addr.isNull() && addr.isGlobal() && !addr.isUniqueLocalUnicast()) {
                 m_details << i18n("IPv6 Address") << addr.toString();
+            } else if (!addr.isNull() && addr.isGlobal() && addr.isUniqueLocalUnicast()) {
+                m_details << i18n("IPv6 ULA Address") << addr.toString();
+            }
+        }
+        if (!device->ipV6Config().gateway().isEmpty()) {
+            QString addr = device->ipV6Config().gateway();
+            if (!addr.isNull()) {
+                m_details << i18n("IPv6 Default Gateway") << addr;
             }
         }
         if (!device->ipV6Config().nameservers().isEmpty()) {
-            QHostAddress addr = device->ipV6Config().nameservers().first();
-            if (!addr.isNull()) {
-                m_details << i18n("IPv6 Nameserver") << addr.toString();
+            QHostAddress addr1 = device->ipV6Config().nameservers().first();
+            QHostAddress addr2 = device->ipV6Config().nameservers().last();
+            if (!addr1.isNull()) {
+                m_details << i18n("IPv6 Primary Nameserver") << addr1.toString();
+            }
+            if (!addr2.isNull() && !addr1.isNull()) {
+                if (addr2 != addr1) {
+                    m_details << i18n("IPv6 Secondary Nameserver") << addr2.toString();
+                }
             }
         }
     }
@@ -641,7 +649,6 @@ void NetworkModelItem::updateDetails() const
                 m_details << i18n("Capabilities") << QStringLiteral("DUN");
             }
             m_details << i18n("MAC Address") << bluetoothDevice->hardwareAddress();
-
         }
     } else if (m_type == NetworkManager::ConnectionSettings::Infiniband) {
         NetworkManager::InfinibandDevice::Ptr infinibandDevice = device.objectCast<NetworkManager::InfinibandDevice>();
@@ -670,8 +677,7 @@ void NetworkModelItem::updateDetails() const
         }
     } else if (m_type == NetworkManager::ConnectionSettings::Adsl) {
         m_details << i18n("Type") << i18n("Adsl");
-    }
-      else if (m_type == NetworkManager::ConnectionSettings::Team) {
+    } else if (m_type == NetworkManager::ConnectionSettings::Team) {
         NetworkManager::TeamDevice::Ptr teamDevice = device.objectCast<NetworkManager::TeamDevice>();
         m_details << i18n("Type") << i18n("Team");
         if (teamDevice) {
