@@ -1,38 +1,25 @@
 /*
-    Copyright 2013 Lukas Tinkl <ltinkl@redhat.com>
-    Copyright 2015 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2013 Lukas Tinkl <ltinkl@redhat.com>
+    SPDX-FileCopyrightText: 2015 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "openvpnadvancedwidget.h"
-#include "ui_openvpnadvanced.h"
 #include "nm-openvpn-service.h"
 #include "settingwidget.h"
+#include "ui_openvpnadvanced.h"
 
+#include <QComboBox>
 #include <QStandardPaths>
 #include <QUrl>
-#include <QComboBox>
 
+#include <KAcceleratorManager>
 #include <KLocalizedString>
 #include <KProcess>
-#include <KAcceleratorManager>
 
-class OpenVpnAdvancedWidget::Private {
+class OpenVpnAdvancedWidget::Private
+{
 public:
     NetworkManager::VpnSetting::Ptr setting;
     KProcess *openvpnCipherProcess = nullptr;
@@ -49,16 +36,17 @@ public:
     class EnumProxyType
     {
     public:
-        enum ProxyType {NotRequired = 0, HTTP = 1, SOCKS = 2};
+        enum ProxyType { NotRequired = 0, HTTP = 1, SOCKS = 2 };
     };
     class EnumHashingAlgorithms
     {
     public:
-        enum HashingAlgorithms {Default = 0, None, Md4, Md5, Sha1, Sha224, Sha256, Sha384, Sha512, Ripemd160};
+        enum HashingAlgorithms { Default = 0, None, Md4, Md5, Sha1, Sha224, Sha256, Sha384, Sha512, Ripemd160 };
     };
-    class EnumCompression {
+    class EnumCompression
+    {
     public:
-        enum Compression {None = 0, LZO, LZ4, LZ4v2, Adaptive, Automatic};
+        enum Compression { None = 0, LZO, LZ4, LZ4v2, Adaptive, Automatic };
     };
 };
 
@@ -78,7 +66,7 @@ OpenVpnAdvancedWidget::OpenVpnAdvancedWidget(const NetworkManager::VpnSetting::P
 
     connect(m_ui->cbCertCheck, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &OpenVpnAdvancedWidget::certCheckTypeChanged);
     connect(m_ui->cmbProxyType, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &OpenVpnAdvancedWidget::proxyTypeChanged);
-    connect(m_ui->cboTLSMode, QOverload<int>::of(&QComboBox::currentIndexChanged), this, [this] (int index) {
+    connect(m_ui->cboTLSMode, QOverload<int>::of(&QComboBox::currentIndexChanged), this, [this](int index) {
         if (index == 0) {
             m_ui->kurlTlsAuthKey->setDisabled(true);
             m_ui->cboDirection->setDisabled(true);
@@ -92,7 +80,7 @@ OpenVpnAdvancedWidget::OpenVpnAdvancedWidget(const NetworkManager::VpnSetting::P
     });
 
     // start openVPN process and get its cipher list
-    const QString openVpnBinary = QStandardPaths::findExecutable("openvpn", QStringList() << "/sbin" << "/usr/sbin");
+    const QString openVpnBinary = QStandardPaths::findExecutable("openvpn", QStringList{"/sbin", "/usr/sbin"});
     const QStringList ciphersArgs(QLatin1String("--show-ciphers"));
     const QStringList versionArgs(QLatin1String("--version"));
 
@@ -462,7 +450,7 @@ void OpenVpnAdvancedWidget::loadConfig()
     d->readConfig = true;
 
     NetworkManager::Setting::SecretFlags type;
-    type = (NetworkManager::Setting::SecretFlags)dataMap[NM_OPENVPN_KEY_HTTP_PROXY_PASSWORD"-flags"].toInt();
+    type = (NetworkManager::Setting::SecretFlags)dataMap[NM_OPENVPN_KEY_HTTP_PROXY_PASSWORD "-flags"].toInt();
     if (!(type & NetworkManager::Setting::NotSaved || type & NetworkManager::Setting::NotRequired)) {
         m_ui->proxyPassword->setText(secrets.value(QLatin1String(NM_OPENVPN_KEY_HTTP_PROXY_PASSWORD)));
     }
@@ -494,7 +482,7 @@ NetworkManager::VpnSetting::Ptr OpenVpnAdvancedWidget::setting() const
     if (m_ui->chkMtu->isChecked()) {
         data.insert(QLatin1String(NM_OPENVPN_KEY_TUNNEL_MTU), QString::number(m_ui->sbMtu->value()));
     }
-    if (m_ui->chkCustomFragmentSize->isChecked() ) {
+    if (m_ui->chkCustomFragmentSize->isChecked()) {
         data.insert(QLatin1String(NM_OPENVPN_KEY_FRAGMENT_SIZE), QString::number(m_ui->sbCustomFragmentSize->value()));
     }
     if (m_ui->chkUseCustomReneg->isChecked()) {
@@ -504,22 +492,22 @@ NetworkManager::VpnSetting::Ptr OpenVpnAdvancedWidget::setting() const
 
     if (m_ui->chkUseCompression->isChecked()) {
         switch (m_ui->cmbUseCompression->currentIndex()) {
-	case Private::EnumCompression::None:
+        case Private::EnumCompression::None:
             data.insert(QLatin1String(NM_OPENVPN_KEY_COMP_LZO), QLatin1String("no-by-default"));
             break;
-	case Private::EnumCompression::LZO:
+        case Private::EnumCompression::LZO:
             data.insert(QLatin1String(NM_OPENVPN_KEY_COMPRESS), QLatin1String("lzo"));
             break;
-	case Private::EnumCompression::LZ4:
+        case Private::EnumCompression::LZ4:
             data.insert(QLatin1String(NM_OPENVPN_KEY_COMPRESS), QLatin1String("lz4"));
             break;
-	case Private::EnumCompression::LZ4v2:
+        case Private::EnumCompression::LZ4v2:
             data.insert(QLatin1String(NM_OPENVPN_KEY_COMPRESS), QLatin1String("lz4-v2"));
             break;
-	case Private::EnumCompression::Adaptive:
+        case Private::EnumCompression::Adaptive:
             data.insert(QLatin1String(NM_OPENVPN_KEY_COMP_LZO), QLatin1String("adaptive"));
             break;
-	case Private::EnumCompression::Automatic:
+        case Private::EnumCompression::Automatic:
             data.insert(QLatin1String(NM_OPENVPN_KEY_COMPRESS), QLatin1String("yes"));
             break;
         }
@@ -600,13 +588,16 @@ NetworkManager::VpnSetting::Ptr OpenVpnAdvancedWidget::setting() const
     case CertCheckType::DontVerify:
         break;
     case CertCheckType::VerifyWholeSubjectExactly:
-        data.insert(QLatin1String(NM_OPENVPN_KEY_VERIFY_X509_NAME), QStringLiteral("%1:%2").arg(NM_OPENVPN_VERIFY_X509_NAME_TYPE_SUBJECT).arg(m_ui->subjectMatch->text()));
+        data.insert(QLatin1String(NM_OPENVPN_KEY_VERIFY_X509_NAME),
+                    QStringLiteral("%1:%2").arg(NM_OPENVPN_VERIFY_X509_NAME_TYPE_SUBJECT).arg(m_ui->subjectMatch->text()));
         break;
     case CertCheckType::VerifyNameExactly:
-        data.insert(QLatin1String(NM_OPENVPN_KEY_VERIFY_X509_NAME), QStringLiteral("%1:%2").arg(NM_OPENVPN_VERIFY_X509_NAME_TYPE_NAME).arg(m_ui->subjectMatch->text()));
+        data.insert(QLatin1String(NM_OPENVPN_KEY_VERIFY_X509_NAME),
+                    QStringLiteral("%1:%2").arg(NM_OPENVPN_VERIFY_X509_NAME_TYPE_NAME).arg(m_ui->subjectMatch->text()));
         break;
     case CertCheckType::VerifyNameByPrefix:
-        data.insert(QLatin1String(NM_OPENVPN_KEY_VERIFY_X509_NAME), QStringLiteral("%1:%2").arg(NM_OPENVPN_VERIFY_X509_NAME_TYPE_NAME_PREFIX).arg(m_ui->subjectMatch->text()));
+        data.insert(QLatin1String(NM_OPENVPN_KEY_VERIFY_X509_NAME),
+                    QStringLiteral("%1:%2").arg(NM_OPENVPN_VERIFY_X509_NAME_TYPE_NAME_PREFIX).arg(m_ui->subjectMatch->text()));
         break;
     case CertCheckType::VerifySubjectPartially:
         data.insert(QLatin1String(NM_OPENVPN_KEY_TLS_REMOTE), m_ui->subjectMatch->text());
@@ -656,7 +647,7 @@ NetworkManager::VpnSetting::Ptr OpenVpnAdvancedWidget::setting() const
         if (!m_ui->proxyUsername->text().isEmpty()) {
             data.insert(QLatin1String(NM_OPENVPN_KEY_HTTP_PROXY_USERNAME), m_ui->proxyUsername->text());
             secretData.insert(QLatin1String(NM_OPENVPN_KEY_HTTP_PROXY_PASSWORD), m_ui->proxyPassword->text());
-            handleOnePasswordType(m_ui->proxyPassword, QLatin1String(NM_OPENVPN_KEY_HTTP_PROXY_PASSWORD"-flags"), data);
+            handleOnePasswordType(m_ui->proxyPassword, QLatin1String(NM_OPENVPN_KEY_HTTP_PROXY_PASSWORD "-flags"), data);
         }
         break;
     case Private::EnumProxyType::SOCKS:
@@ -711,7 +702,7 @@ void OpenVpnAdvancedWidget::proxyTypeChanged(int type)
     }
 }
 
-void OpenVpnAdvancedWidget::handleOnePasswordType(const PasswordField *passwordField, const QString & key, NMStringMap & data) const
+void OpenVpnAdvancedWidget::handleOnePasswordType(const PasswordField *passwordField, const QString &key, NMStringMap &data) const
 {
     const PasswordField::PasswordOption option = passwordField->passwordOption();
     switch (option) {
